@@ -3,18 +3,18 @@ from dataclasses import dataclass
 import commands2 as commands
 import commands2.button
 
-from robotpy_toolkit_7407.oi.joysticks import _Joysticks
+from robotpy_toolkit_7407.oi.joysticks import Joysticks
 
 
 @dataclass
-class _Button:
+class Button:
     controller_id: int
 
     def __call__(self) -> commands.button.Button: ...
 
 
 @dataclass
-class DefaultButton(_Button):
+class DefaultButton(Button):
     """
     Wrapper for wpilib button
     """
@@ -23,13 +23,13 @@ class DefaultButton(_Button):
     def __call__(self) -> commands.button.Button:
         if self.button_id < 0:
             return commands.button.Button(
-                lambda: _Joysticks.joysticks[self.controller_id].getRawAxis(-self.button_id) > 0.8
+                lambda: Joysticks.joysticks[self.controller_id].getRawAxis(-self.button_id) > 0.8
             )
-        return commands.button.JoystickButton(_Joysticks.joysticks[self.controller_id], self.button_id)
+        return commands.button.JoystickButton(Joysticks.joysticks[self.controller_id], self.button_id)
 
 
 @dataclass
-class AxisButton(_Button):
+class AxisButton(Button):
     """
     Wrapper for wpilib axis button
     """
@@ -39,5 +39,5 @@ class AxisButton(_Button):
 
     def __call__(self) -> commands.button.Button:
         return commands.button.Button(
-            lambda: self.range_min <= _Joysticks.joysticks[self.controller_id].getRawAxis(self.axis_id) <= self.range_max
+            lambda: self.range_min <= Joysticks.joysticks[self.controller_id].getRawAxis(self.axis_id) <= self.range_max
         )
