@@ -1,3 +1,3 @@
 from robotpy_toolkit_7407.sensors.gyro.ADIS16448 import GyroADIS16448
 from robotpy_toolkit_7407.sensors.gyro.PigeonIMU import PigeonIMUGyro_Wrapper
-from robotpy_toolkit_7407.sensors.gyro.base_gyro import Gyro
\ No newline at end of file
+from robotpy_toolkit_7407.sensors.gyro.base_gyro import BaseGyro
\ No newline at end of file
